==> oregano_0.23.orig.tar.gz: oregano-0.23/src/xml-helper.h <==
/*
 * xml-helper.h
 *
 * 
 * Author: 
 *  Richard Hult <rhult@hem.passagen.se>
 * 
 *  http://www.dtek.chalmers.se/~d4hult/oregano/ 
 * 
 * Copyright (C) 1999,2000  Richard Hult 
 * 
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the 
 * License, or (at your option) any later version. 
 * 
 * This program is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __XML_HELPER_H
#define __XML_HELPER_H

#include <gnome.h>
#include "xml-compat.h"

//#include <gnome-xml/parser.h>
//#include <gnome-xml/parserInternals.h>

int oreganoXmlSAXParseFile (xmlSAXHandlerPtr sax, gpointer user_data, const gchar *filename);
void xmlSetGnomeCanvasPoints (xmlNodePtr node, const char *name, GnomeCanvasPoints *val);
void xmlSetValue (xmlNodePtr node, const char *name, const char *val);
void xmlSetIntValue (xmlNodePtr node, const char *name, int val);
void xmlSetDoubleValue (xmlNodePtr node, const char *name, double val);
void xmlSetCoordinate (xmlNodePtr node, const char *name, double x, double y);
void xmlSetCoordinates (xmlNodePtr node, const char *name, double x1, double y1, double x2, double y2);

#endif

==> oregano_0.69.0.orig.tar.gz: oregano-0.69.0/src/xml-helper.h <==
/*
 * xml-helper.h
 *
 *
 * Authors:
 *  Richard Hult <rhult@hem.passagen.se>
 *  Ricardo Markiewicz <rmarkie@fi.uba.ar>
 *  Andres de Barbara <adebarbara@fi.uba.ar>
 *
 * Web page: http://arrakis.lug.fi.uba.ar/
 *
 * Copyright (C) 1999-2001  Richard Hult
 * Copyright (C) 2003,2004  LUGFI
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#ifndef __XML_HELPER_H
#define __XML_HELPER_H

#include <gnome.h>
#include "xml-compat.h"

/*#include <gnome-xml/parser.h>*/
/*#include <gnome-xml/parserInternals.h>*/

int oreganoXmlSAXParseFile (xmlSAXHandlerPtr sax,
	gpointer user_data, const gchar *filename);

void xmlSetGnomeCanvasPoints (xmlNodePtr node,
	const char *name, GnomeCanvasPoints *val);

void xmlSetValue (xmlNodePtr node, const char *name, const char *val);

void xmlSetIntValue (xmlNodePtr node, const char *name, int val);

void xmlSetDoubleValue (xmlNodePtr node, const char *name, double val);

void xmlSetCoordinate (xmlNodePtr node, const char *name, double x, double y);

void xmlSetCoordinates (xmlNodePtr node, const char *name,
	double x1, double y1, double x2, double y2);

#endif
